aboutsummaryrefslogtreecommitdiff
path: root/src/init.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/init.h')
-rw-r--r--src/init.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/init.h b/src/init.h
index da8255cda3..ead5f5e0d2 100644
--- a/src/init.h
+++ b/src/init.h
@@ -26,8 +26,10 @@ namespace node {
struct NodeContext;
} // namespace node
/** Initialize node context variables. */
void InitContext(node::NodeContext& node);
+/** Return whether node shutdown was requested. */
+bool ShutdownRequested(node::NodeContext& node);
/** Interrupt threads */
void Interrupt(node::NodeContext& node);
@@ -26,8 +26,10 @@ namespace node {
struct NodeContext;
} // namespace node
-/** Initialize node context variables. */
+/** Initialize node context shutdown and args variables. */
void InitContext(node::NodeContext& node);